#!/usr/bin/perl -w
###########################################################
#
#DOMpro: Protein Domain Prediction Program
#configure.pl: to configure the installation of DOMpro
#
#Contact: Jianlin cheng at jianlinc@uci.edu
#Institute for Genomics and Bioinformatics
#School of Information and Computer Science
#University of California, Irvine
#
##########################################################

#######Customize settings here##############
#
#set installation directory of DOMpro
$install_dir = "/home/baldig/jianlin/dompro1.0/";
#
#set the fullpath of pspro bin directory
$pspro_dir = "/home/baldig/jianlin/sspro4/";
#
######End of Customization##################


################Don't Change the code below##############
if (! -d $install_dir)
{
	die "can't find installation directory.\n";
}
if ( substr($install_dir, length($install_dir) - 1, 1) ne "/" )
{
	$install_dir .= "/"; 
}
if (! -d $pspro_dir)
{
	die "can't find Pspro directory.\n";
}
if ( substr($pspro_dir, length($pspro_dir) - 1, 1) ne "/" )
{
	$pspro_dir .= "/"; 
}

#check if the installation directory is right
#the configuration file must run in the installation directory
$cur_dir = `pwd`;  
chomp $cur_dir; 
$configure_file = "$cur_dir/configure.pl";
if (! -f $configure_file || $install_dir ne "$cur_dir/")
{
	die "Please check the installation directory setting and run the configure program there.\n";
}

$bin_dir = "${install_dir}bin/";
$model_dir = "${install_dir}model/";
$script_dir = "${install_dir}script/";
$server_dir = "${install_dir}server/";

if ( ! -d $bin_dir || ! -d $model_dir || ! -d $script_dir
   || ! -d $server_dir )
{
	die "some sub directories don't exist. check the installation tar ball.\n";
}

#generate model definition file
$dopro_exe = "${server_dir}predict_seq";
$dopro_sh = "${bin_dir}predict_dom.sh";
$dom_model_dir = "${model_dir}dom/";
$dom_model_def = "${model_dir}model.def";
$pspro_exe = "${pspro_dir}bin/predict_ss_sa.sh"; 

print "generate DOMpro server script...\n";
open(SERVER_SH, ">$dopro_sh") || die "can't write dopro shell script.\n";
print SERVER_SH "#!/bin/sh\n#predict domain for one sequence.\n";
print SERVER_SH "if [ \$# -ne 2 ]\n";
print SERVER_SH "then\n\techo \"need 2 parameters:fasta seq_file, output prefix.\"\n\texit 1\nfi\n";
print SERVER_SH "${script_dir}predict_dom.pl $script_dir $pspro_exe $dopro_exe $dom_model_def \$1 \$2 \n"; 
close SERVER_SH;

print "generate DOMpro model definition file...\n";
opendir(MODEL_DIR, "$dom_model_dir") || die "can't open the dopro model dir.\n";
open(MODEL_DEF, ">$dom_model_def") || die "can't create dopro model def file.\n";
@file_list = readdir(MODEL_DIR);
closedir(MODEL_DIR); 
if (@file_list < 3)
{
	die "can't find accpro model file. check intallation tar ball.\n";
}
$model_num = @file_list;
$model_num -= 2; 
print MODEL_DEF "$model_num 2\n";
while (@file_list)
{
	$model_file = shift @file_list;
	if ($model_file ne "." && $model_file ne ".." && $model_file ne "CVS")
	{
		print MODEL_DEF "$dom_model_dir$model_file\n";
	}
}
close MODEL_DEF; 


